@@ -1,12 +1,13 @@
 package Parse::BBCode::HTML;
-use strict;
+$Parse::BBCode::HTML::VERSION = '0.15_001'; # TRIAL
+
+$Parse::BBCode::HTML::VERSION = '0.15001';use strict;
 use warnings;
 use Carp qw(croak carp);
 use URI::Escape;
 use base 'Exporter';
 our @EXPORT_OK = qw/ &defaults &default_escapes &optional /;
 
-our $VERSION = '0.05';
 my $email_valid = 0;
 eval {
     require
